@@ -106,6 +106,7 @@ func main() {
 		rules.HuggingFaceAccessToken(),
 		rules.HuggingFaceOrganizationApiToken(),
 		rules.Intercom(),
+		rules.Intra42ClientSecret(),
 		rules.JFrogAPIKey(),
 		rules.JFrogIdentityToken(),
 		rules.JWT(),
@@ -132,6 +133,7 @@ func main() {
 		rules.NewRelicUserID(),
 		rules.NewRelicUserKey(),
 		rules.NewRelicBrowserAPIKey(),
+		rules.NewRelicInsertKey(),
 		rules.NPM(),
 		rules.NytimesAccessToken(),
 		rules.OktaAccessToken(),
