@@ -8,7 +8,7 @@ import (
 func AdafruitAPIKey() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Adafruit API Key",
+		Description: "Identified a potential Adafruit API Key, which could lead to unauthorized access to Adafruit services and sensitive data exposure.",
 		RuleID:      "adafruit-api-key",
 		Regex:       generateSemiGenericRegex([]string{"adafruit"}, alphaNumericExtendedShort("32"), true),
 		Keywords:    []string{"adafruit"},
