@@ -10,7 +10,7 @@ import (
 func Clojars() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Clojars API token",
+		Description: "Uncovered a possible Clojars API token, risking unauthorized access to Clojure libraries and potential code manipulation.",
 		RuleID:      "clojars-api-token",
 		Regex:       regexp.MustCompile(`(?i)(CLOJARS_)[a-z0-9]{60}`),
 		Keywords:    []string{"clojars"},
