@@ -11,7 +11,7 @@ func Duffel() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "duffel-api-token",
-		Description: "Duffel API token",
+		Description: "Uncovered a Duffel API token, which may compromise travel platform integrations and sensitive customer data.",
 		Regex:       regexp.MustCompile(`duffel_(test|live)_(?i)[a-z0-9_\-=]{43}`),
 		Keywords:    []string{"duffel"},
 	}
