@@ -10,7 +10,7 @@ import (
 func Dynatrace() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Dynatrace API token",
+		Description: "Detected a Dynatrace API token, potentially risking application performance monitoring and data exposure.",
 		RuleID:      "dynatrace-api-token",
 		Regex:       regexp.MustCompile(`dt0c01\.(?i)[a-z0-9]{24}\.[a-z0-9]{64}`),
 		Keywords:    []string{"dynatrace"},
