@@ -8,7 +8,7 @@ import (
 func FastlyAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Fastly API key",
+		Description: "Uncovered a Fastly API key, which may compromise CDN and edge cloud services, leading to content delivery and security issues.",
 		RuleID:      "fastly-api-token",
 		Regex:       generateSemiGenericRegex([]string{"fastly"}, alphaNumericExtended("32"), true),
 
