@@ -9,7 +9,7 @@ func FinnhubAccessToken() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "finnhub-access-token",
-		Description: "Finnhub Access Token",
+		Description: "Found a Finnhub Access Token, risking unauthorized access to financial market data and analytics.",
 		Regex:       generateSemiGenericRegex([]string{"finnhub"}, alphaNumeric("20"), true),
 
 		Keywords: []string{
